<p align="center">
<img align="center" height="200" src="assets/logo_w_text.svg">
<br>
 <b>Your go-to package for topic modeling with contextual representations from transformers. </b></p>

### Intentions:
 - Provide simple, robust and fast implementations of existing approaches (BERTopic, Top2Vec, CTM) with minimal dependencies.
 - Implement state-of-the-art approaches from my papers. (papers work-in-progress)
 - Put all approaches in a broader conceptual framework.
 - Provide clear and extensive documentation about the best use-cases for each model.
 - Make the models' API streamlined and compatible with topicwizard and scikit-learn.
 - Develop smarter, transformer-based evaluation metrics.

(Stay tuned...)
